
import { useState, startTransition } from "react";
import { Menu, X, Globe } from "lucide-react";
import { useStaticTexts } from "@/hooks/useStaticTexts";
import { useLanguage } from "@/context/LanguageContext";
import { usePageSections } from "@/hooks/usePageSections";

const LANG_OPTIONS = [
  { code: "cs", label: "Čeština", short: "CS" },
  { code: "en", label: "English", short: "EN" }
];

const NAV_SECTION_ANCHORS: Record<string, { labelKey: string; sectionId: string }> = {
  Hero: { labelKey: "hero", sectionId: "hero" },
  About: { labelKey: "about", sectionId: "about" },
  Experience: { labelKey: "experience", sectionId: "about" },
  Services: { labelKey: "services", sectionId: "services" },
  Technologies: { labelKey: "skills", sectionId: "technologies" },
  Projects: { labelKey: "projects", sectionId: "projects" },
  Clients: { labelKey: "clients", sectionId: "clients" },
  Contact: { labelKey: "contact", sectionId: "contact" },
};

const Header = () => {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const { language, setLanguage } = useLanguage();
  const { data: navTexts } = useStaticTexts('navigation', language);
  const { data: sections = [] } = usePageSections(language);

  // Filtrujeme pouze viditelné sekce kromě "Hero" (pro navigaci)
  const visibleNavSections = sections.filter(
    (section) => section.is_visible && NAV_SECTION_ANCHORS[section.component_name] && section.component_name !== "Hero"
  );
  // Všechny sekce (pro mobilní menu) - "Hero" může být použito jako logo/odkaz vlevo

  const scrollToSection = (sectionId: string) => {
    // First, try to find the element
    let element = document.getElementById(sectionId);
    
    if (!element) {
      // If element doesn't exist, force load the lazy section using startTransition
      startTransition(() => {
        const forceLoadEvent = new CustomEvent('forceLoadSection', {
          detail: { sectionId }
        });
        window.dispatchEvent(forceLoadEvent);
      });
      
      // Wait a bit for the lazy section to load, then try scrolling again
      setTimeout(() => {
        element = document.getElementById(sectionId);
        if (element) {
          element.scrollIntoView({ behavior: 'smooth' });
        }
      }, 100);
    } else {
      // Element exists, scroll immediately
      element.scrollIntoView({ behavior: 'smooth' });
    }
    
    setIsMenuOpen(false);
  };

  // Toggle language
  const handleLanguageToggle = () => {
    setLanguage(language === "cs" ? "en" : "cs");
  };
  // Kód jazyka, na který se přepíná
  const switchTo = language === "cs" ? LANG_OPTIONS.find(l => l.code === "en") : LANG_OPTIONS.find(l => l.code === "cs");

  return (
    <header className="fixed top-0 left-0 right-0 z-50 bg-background/80 backdrop-blur-lg border-b border-border">
      <div className="container mx-auto px-6 py-4">
        <div className="flex items-center justify-between">
          {/* Logo vlevo je nyní odkaz scrollující na #hero */}
          <button
            className="text-2xl font-bold text-foreground/80 hover:text-foreground flex-shrink-0 focus:outline-none transition-colors"
            onClick={() => scrollToSection('hero')}
            aria-label="Přejít na začátek stránky"
            type="button"
          >
            MATYAS HERMAN
          </button>
          {/* Pravá část: navigace + jazyk */}
          <div className="flex items-center justify-end flex-1">
            {/* Desktop Navigation */}
            <nav className="hidden md:flex items-center space-x-8">
              {visibleNavSections.map(section => {
                const { component_name } = section;
                const navInfo = NAV_SECTION_ANCHORS[component_name];
                return (
                  <button
                    key={component_name}
                    onClick={() => scrollToSection(navInfo.sectionId)}
                    className="text-foreground/70 hover:text-foreground transition-colors"
                  >
                    {navTexts?.[navInfo.labelKey] || navInfo.labelKey.charAt(0).toUpperCase() + navInfo.labelKey.slice(1)}
                  </button>
                );
              })}
              {/* Jazykový přepínač s Globe ikonou */}
              <button
                onClick={handleLanguageToggle}
                className="ml-6 flex items-center gap-1.5 text-foreground/80 hover:text-foreground text-base font-medium transition-colors px-3 py-1 rounded"
                aria-label="Změna jazyka"
                type="button"
              >
                <Globe size={18} className="inline align-middle" />
                {switchTo?.short}
              </button>
            </nav>
            {/* Mobile Menu Button */}
            <button
              className="md:hidden ml-4"
              onClick={() => setIsMenuOpen(!isMenuOpen)}
              aria-label="Otevřít menu"
            >
              {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
            </button>
          </div>
        </div>
        {/* Mobilní menu */}
        {isMenuOpen && (
          <nav className="md:hidden mt-4 pb-4 space-y-4">
            {visibleNavSections.map(section => {
              const { component_name } = section;
              const navInfo = NAV_SECTION_ANCHORS[component_name];
              return (
                <button
                  key={component_name}
                  onClick={() => scrollToSection(navInfo.sectionId)}
                  className="block text-foreground/70 hover:text-foreground transition-colors w-full text-left"
                >
                  {navTexts?.[navInfo.labelKey] || navInfo.labelKey.charAt(0).toUpperCase() + navInfo.labelKey.slice(1)}
                </button>
              );
            })}
            {/* Mobile jazykový přepínač s Globe ikonou */}
            <button
              onClick={handleLanguageToggle}
              className="mt-4 flex items-center gap-1.5 text-foreground/80 hover:text-foreground text-base font-medium transition-colors px-3 py-1 rounded w-full text-left"
              aria-label="Změna jazyka"
              type="button"
            >
              <Globe size={18} className="inline align-middle" />
              {switchTo?.short}
            </button>
          </nav>
        )}
      </div>
    </header>
  );
};

export default Header;
